@@ -160,9 +160,7 @@ class Connection(object):
         return self._transport.isOpen()
 
     def clear(self, query_id):
-        # self._client.clear(query_id)
-        # TODO: Implement clear.
-        pass
+        self._client.clear(query_id)
 
     def reopen(self):
         self._transport.close()
